@@ -8,7 +8,7 @@ from collections import Counter
 from nltk.corpus import stopwords
 # 分词
 from nltk.tokenize import word_tokenize
-nltk.download('stopwords')
+# nltk.download('stopwords')
 # stopwords.words('english')
 def tosrt(x):
     """
@@ -41,8 +41,8 @@ def pre_clear_text(text):
     text=text.lower()
 
     # text = ' '.join([word for word in word_tokenize(text) if word not in stopwords_dict])
-    words=[word for word in word_tokenize(text) if word not in stopwords_dict]
-    # words=word_tokenize(text)
+    # words=[word for word in word_tokenize(text) if word not in stopwords_dict]
+    words=word_tokenize(text)
 
     return words
 
